.. raw:: html

    <object data="_static/pymedphys_title.svg" type="image/svg+xml" class="title-logo"></object>

.. include:: README.rst
   :start-after: START_OF_DOCS_IMPORT
   :end-before: END_OF_DOCS_IMPORT

.. _`Release Notes`: release-notes.html

.. _`App Users Guide`: app/index.html
.. _`Library Users Guide`: lib/index.html
.. _`CLI Users Guide`: cli/index.html
.. _`Contributors Guide`: contrib/index.html
.. _`General`: general/index.html

.. toctree::
    :hidden:
    :maxdepth: 3
    :caption: App Users Guide

    app/index
    app/ref/index

.. toctree::
    :hidden:
    :maxdepth: 3
    :caption: Library Users Guide

    lib/index
    lib/tutes/index
    lib/howto/index
    lib/ref/index
    lib/background/index

.. toctree::
    :hidden:
    :maxdepth: 3
    :caption: CLI Users Guide

    cli/index
    cli/ref/index

.. toctree::
    :hidden:
    :maxdepth: 3
    :caption: Contributors Guide

    contrib/index
    contrib/documentation
    contrib/setups/index
    contrib/other/index


.. toctree::
    :hidden:
    :maxdepth: 3
    :caption: General

    general/index
    release-notes
    general/file-structure
    general/open-source-benefits
